@@ -24,15 +24,15 @@ betalink <- function(n1,n2,bf=B01){
    # Why can't igraph just expose the name of edges? WHY?
    # This is fugly
    # I hate this bullshit
-   e1 <- plyr::aaply(igraph::get.edgelist(n1), 1, function(x) stringr::str_c(x[order(x)], collapse='--', paste='_'))
-   e2 <- plyr::aaply(igraph::get.edgelist(n2), 1, function(x) stringr::str_c(x[order(x)], collapse='--', paste='_'))
+   e1 <- plyr::aaply(igraph::get.edgelist(n1), 1, function(x) stringr::str_c(x, collapse='--', paste='_'))
+   e2 <- plyr::aaply(igraph::get.edgelist(n2), 1, function(x) stringr::str_c(x, collapse='--', paste='_'))
    beta_WN <- bf(betapart(e1, e2))
    if(length(vs)>=2)
    {
       sn1 <- igraph::induced.subgraph(n1, which(igraph::V(n1)$name %in% vs))
       sn2 <- igraph::induced.subgraph(n2, which(igraph::V(n2)$name %in% vs))
-      se1 <- plyr::aaply(igraph::get.edgelist(sn1), 1, function(x) stringr::str_c(x[order(x)], collapse='--', paste='_'))
-      se2 <- plyr::aaply(igraph::get.edgelist(sn2), 1, function(x) stringr::str_c(x[order(x)], collapse='--', paste='_'))
+      se1 <- plyr::aaply(igraph::get.edgelist(sn1), 1, function(x) stringr::str_c(x, collapse='--', paste='_'))
+      se2 <- plyr::aaply(igraph::get.edgelist(sn2), 1, function(x) stringr::str_c(x, collapse='--', paste='_'))
       beta_OS <- bf(betapart(se1, se2))
       beta_ST <- beta_WN - beta_OS
    } else {
